/// <reference types="node" />
import { EventEmitter } from 'events';
import { Commands, SocketPayloadsMap } from './types';
import { Auth, Booth } from './modules';
export interface IUWaveOptions {
    apiBaseUrl: string;
    wsConnectionString: string;
    authImmediately?: boolean;
    credentials?: {
        email: string;
        password: string;
    };
}
export declare class uWave {
    private jwt?;
    private socketToken?;
    private socket?;
    private emitter;
    options: IUWaveOptions;
    private modules;
    static KEEP_ALIVE_MESSAGE: string;
    constructor(options: IUWaveOptions);
    get auth(): Auth;
    get booth(): Booth;
    sendChat(message: string): void;
    vote(direction: 1 | -1): void;
    request<I extends {}, R extends {}>(method: 'get' | 'post' | 'put' | 'patch' | 'delete', endpoint: string, data?: I): Promise<R>;
    get<I, R>(endpoint: string, query?: I): Promise<R>;
    post<I, R>(endpoint: string, data?: I): Promise<R>;
    put<I, R>(endpoint: string, data?: I): Promise<R>;
    patch<I, R>(endpoint: string, data?: I): Promise<R>;
    delete<I extends {}, R>(endpoint: string, query?: I): Promise<R>;
    get isConnected(): boolean;
    once<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    on<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    off<E extends Commands>(eventName: E, listener: (payload: SocketPayloadsMap[E]) => void): EventEmitter;
    connect(): void;
    disconnect(): void;
    private connectSocket;
    private onSocketOpen;
    private onSocketClose;
    private onSocketError;
    private onSocketMessage;
    private emit;
    private send;
}
